Exception: ENM::InvalidDefaultError

Inherits:
Error
  • Object
show all
Defined in:
lib/enm.rb

Overview

An error that is raised when trying to specify a default value that is not present in the enum.