Exception: ENM::NoCurrentNamespaceError

Inherits:
Error
  • Object
show all
Defined in:
lib/enm.rb

Overview

An error that is raised when trying to access the current namespace when it has yet to be initialized.