Libraries
»
enm
(0.1.0)
»
Index (I)
»
ENM
»
InvalidDefaultError
Exception: ENM::InvalidDefaultError
Inherits:
Error
Object
StandardError
Error
ENM::InvalidDefaultError
show all
Defined in:
lib/enm.rb
Overview
An error that is raised when trying to specify a default value that is not present in the enum.